@@ -9,21 +9,21 @@ Core functions used by unumpy and some of its submodules.
 # imports one of the submodules in order to make it available to the
 # user.
 
-
+from __future__ import division
 
 # Standard modules:
+from builtins import next
+from builtins import zip
+from builtins import range
 import sys
-import itertools
 import inspect
 
 # 3rd-party modules:
 import numpy
-from numpy.core import numeric
 
 # Local modules:
 import uncertainties.umath_core as umath_core
 import uncertainties.core as uncert_core
-from uncertainties.core import deprecation
 
 __all__ = [
     # Factory functions:
@@ -172,9 +172,11 @@ def wrap_array_func(func):
         for element in arr.flat:
             # floats, etc. might be present
             if isinstance(element, uncert_core.AffineScalarFunc):
-                # !!!! This forces an evaluation of the
+                # !!!! The following forces an evaluation of the
                 # derivatives!? Isn't this very slow, when
                 # working with a large number of arrays?
+                #
+                # !! set() is only needed for Python 2 compatibility:
                 variables |= set(element.derivatives.keys())
 
         # If the matrix has no variables, then the function value can be
@@ -233,7 +235,7 @@ def wrap_array_func(func):
             # Update of the list of variables and associated
             # derivatives, for each element:
             for (derivative_dict, derivative_value) in (
-                list(zip(derivatives.flat, numerical_deriv.flat))):
+                zip(derivatives.flat, numerical_deriv.flat)):
 
                 if derivative_value:
                     derivative_dict[var] = derivative_value
@@ -281,8 +283,7 @@ def uarray(nominal_values, std_devs=None):
     """
 
     if std_devs is None:  # Obsolete, single tuple argument call
-        deprecation('uarray() should now be called with two arguments.')
-        (nominal_values, std_devs) = nominal_values
+        raise TypeError('uarray() should be called with two arguments.')
 
     return (numpy.vectorize(
         # ! Looking up uncert_core.Variable beforehand through
@@ -384,7 +385,8 @@ def func_with_deriv_to_uncert_func(func_with_derivatives):
         for element in array_version.flat:
             # floats, etc. might be present
             if isinstance(element, uncert_core.AffineScalarFunc):
-                variables |= element.derivatives.keys()
+                # !!! set() is only needed for Python 2 compatibility:
+                variables |= set(element.derivatives.keys())
 
         array_nominal = nominal_values(array_version)
         # Function value, then derivatives at array_nominal (the
@@ -568,28 +570,6 @@ pinv = uncert_core.set_doc("""
 
 ########## Matrix class
 
-class CallableStdDevs(numpy.matrix):
-    '''
-    Class for standard deviation results, which used to be
-    callable. Provided for compatibility with old code. Issues an
-    obsolescence warning upon call.
-
-    New objects must be created by passing an existing
-    '''
-
-    def __new__(cls, matrix):
-        # The following prevents a copy of the original matrix, which
-        # could be expensive, and is unnecessary (the CallableStdDevs
-        # is just a wrapping around the original matrix, which can be
-        # modified):
-        matrix.__class__ = cls
-        return matrix
-
-    def __call__ (self):
-        deprecation('the std_devs attribute should not be called'
-                    ' anymore: use .std_devs instead of .std_devs().')
-        return self
-
 class matrix(numpy.matrix):
     # The name of this class is the same as NumPy's, which is why it
     # does not follow PEP 8.
@@ -604,10 +584,10 @@ class matrix(numpy.matrix):
         # scalar and of a matrix containing objects (when the
         # arguments are given in this order).  We go around this
         # limitation:
-        if numeric.isscalar(other):
-            return numeric.dot(self, other)
+        if numpy.isscalar(other):
+            return numpy.dot(self, other)
         else:
-            return numeric.dot(other, self)  # The order is important
+            return numpy.dot(other, self)  # The order is important
 
     def getI(self):
         """Matrix inverse or pseudo-inverse."""
@@ -634,7 +614,7 @@ class matrix(numpy.matrix):
     # the first ones to have such methods?
     @property
     def std_devs(self):
-        return CallableStdDevs(std_devs(self))
+        return numpy.matrix(std_devs(self))
 
 def umatrix(nominal_values, std_devs=None):
     """
@@ -648,8 +628,7 @@ def umatrix(nominal_values, std_devs=None):
     """
 
     if std_devs is None:  # Obsolete, single tuple argument call
-        deprecation('umatrix() should now be called with two arguments.')
-        (nominal_values, std_devs) = nominal_values
+        raise TypeError('umatrix() should be called with two arguments.')
 
     return uarray(nominal_values, std_devs).view(matrix)
 
